# citation-deaths
This repository contains 
  the code and data I used to analyze the deaths of a million citations in Sociology articles.
The repository provides code and documentation for producing all analyses and figures in the final paper.

# Installation

`pip install science2`
